==> theme-bootstrap-2.0.42.tgz: package/src/components/refill-balance/buy-with-card/buy-with-card.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage, FormattedHTMLMessage } from 'react-intl';

import Button from 'reactstrap/lib/Button';

import { IconUsd } from '../../icons/icon-usd/icon-usd';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';
import { InputWithClipboard } from '../../form/input-with-clipboard/input-with-clipboard';

import GA from '../../../helpers/ga';
import { checkValidAmountValue } from '../../../helpers/validate';
import { CHAR_CODES } from '../../../constants';

import './buy-with-card.scss';

const copyClickGA = () => GA.event({ category: 'BuySCR', action: 'fiat-Copy eth address' });
const createAccGA = () => GA.event({ category: 'BuySCR', action: 'fiat-Create acc' });

export class BuyWithCard extends Component {
  static propTypes = {
    scrValue: PropTypes.string,
    usdValue: PropTypes.string,
    isLoading: PropTypes.bool,
    ethAddress: PropTypes.string,
    usdErrorMsg: PropTypes.string,
    onScrChange: PropTypes.func.isRequired,
    onUsdChange: PropTypes.func.isRequired,
    scrErrorMsg: PropTypes.string,
    scrFraction: PropTypes.number.isRequired,
    usdFraction: PropTypes.number.isRequired,
    onBackClick: PropTypes.func.isRequired,
    isScrLoading: PropTypes.bool,
    isUsdLoading: PropTypes.bool,
  };

  static defaultProps = {
    scrValue: '',
    usdValue: '',
    isLoading: false,
    ethAddress: null,
    scrErrorMsg: '',
    usdErrorMsg: '',
    isScrLoading: false,
    isUsdLoading: false,
  };

  onKeyPress = (evt) => {
    const { which, keyCode } = evt;
    const charCode = which || keyCode;
    if ((charCode > CHAR_CODES.CONTROL &&
      ((charCode < CHAR_CODES.ZERO && charCode !== CHAR_CODES.DOT)
      || charCode > CHAR_CODES.NINE))
    ) {
      evt.preventDefault();
    }
  }

  scrChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !checkValidAmountValue(value, this.props.scrFraction)) {
      return;
    }

    this.props.onScrChange(value);
  }

  usdChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !checkValidAmountValue(value, this.props.usdFraction)) {
      return;
    }

    this.props.onUsdChange(value);
  }

  onBackClick = () => {
    GA.event({ category: 'BuySCR', action: 'fiat-Go back' });
    this.props.onBackClick();
  }

  render() {
    const {
      isLoading, ethAddress, scrValue, isScrLoading, scrErrorMsg, usdValue, isUsdLoading, usdErrorMsg,
    } = this.props;

    return (
      <div className="buy-with-card-step">
        <FormattedMessage id="universal.balance.refill.buy-with-card.title">
          {text => <span className="h3 d-inline-block text-center mb-4_5">{text}</span>}
        </FormattedMessage>

        <div className="buy-with-card-step-item d-flex mb-2_5">
          <div className="mr-2 pt-0_5">
            <span className="buy-with-card-step-number d-flex align-items-center justify-content-center rounded-circle border h5p">
              1
            </span>
          </div>

          <div className="align-self-center">
            <FormattedHTMLMessage id="universal.balance.refill.buy-with-card.steps.1" />
          </div>
        </div>

        <div className="buy-with-card-step-item d-flex mb-1_5">
          <div className="mr-2 pt-0_5">
            <span className="buy-with-card-step-number d-flex align-items-center justify-content-center rounded-circle border h5p">
              2
            </span>
          </div>

          <div className="align-self-center">
            <span className=" d-inline-block mb-1_5">
              <FormattedHTMLMessage id="universal.balance.refill.buy-with-card.steps.2" />
            </span>

            <InputWithClipboard value={ethAddress} isLoading={isLoading} onCopyClick={copyClickGA} />
          </div>
        </div>

        <div className="buy-with-card-step-item d-flex mb-3_5">
          <div className="mr-2 pt-0_5">
            <span className="buy-with-card-step-number d-flex align-items-center justify-content-center rounded-circle border h5p">
              3
            </span>
          </div>

          <div className="align-self-center">
            <FormattedMessage id="universal.balance.refill.buy-with-card.steps.3" />
          </div>
        </div>

        <div className="d-flex align-items-center mb-1_5">
          <div className="buy-with-card-step-divider position-relative w-100" />
          <FormattedMessage id="universal.balance.refill.buy-with-card.calc-amount">
            {text => (
              <span className="buy-with-card-step-divider-title text-nowrap mx-1">{text}</span>
            )}
          </FormattedMessage>
          <div className="buy-with-card-step-divider position-relative w-100" />
        </div>

        <div className="d-flex mb-5">
          <InputWithIcon
            icon={<IconUsd />}
            value={usdValue}
            errorMsg={usdErrorMsg}
            onChange={this.usdChangeHandler}
            isLoading={isUsdLoading}
            onKeyPress={this.onKeyPress}
          />
          <span className="h5 mx-1_5 pt-2 modal-content-text-hint">=</span>
          <InputWithIcon
            icon={<IconScr />}
            value={scrValue}
            errorMsg={scrErrorMsg}
            onChange={this.scrChangeHandler}
            isLoading={isScrLoading}
            onKeyPress={this.onKeyPress}
          />
        </div>

        <FormattedMessage id="universal.balance.refill.buy-with-card.button.href">
          {href => (
            <Button color="primary" block tag="a" href={href} onClick={createAccGA} target="_blank" className="mb-1_5">
              <FormattedMessage id="universal.balance.refill.buy-with-card.button.text" />
            </Button>
          )}
        </FormattedMessage>

        <div className="text-center">
          <FormattedMessage id="universal.balance.refill.buy-with-card.back">
            {text => (
              <span
                role="button"
                tabIndex="0"
                className="buy-with-card-step-back text-small"
                onClick={this.onBackClick}
                onKeyPress={this.onBackClick}
              >
                ←{text}
              </span>
            )}
          </FormattedMessage>
        </div>
      </div>
    );
  }
}

==> theme-bootstrap-2.0.44.tgz: package/src/components/refill-balance/buy-with-card/buy-with-card.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage, FormattedHTMLMessage } from 'react-intl';

import Button from 'reactstrap/lib/Button';

import { IconUsd } from '../../icons/icon-usd/icon-usd';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';
import { InputWithClipboard } from '../../form/input-with-clipboard/input-with-clipboard';

import GA from '../../../helpers/ga';
import { checkValidAmountValue } from '../../../helpers/validate';
import { CHAR_CODES } from '../../../constants';

import './buy-with-card.scss';

const copyClickGA = () => GA.event({ category: 'BuySCR', action: 'fiat-Copy eth address' });
const createAccGA = () => GA.event({ category: 'BuySCR', action: 'fiat-Create acc' });

export class BuyWithCard extends Component {
  static propTypes = {
    scrValue: PropTypes.string,
    usdValue: PropTypes.string,
    isLoading: PropTypes.bool,
    ethAddress: PropTypes.string,
    usdErrorMsg: PropTypes.string,
    onScrChange: PropTypes.func.isRequired,
    onUsdChange: PropTypes.func.isRequired,
    scrErrorMsg: PropTypes.string,
    scrFraction: PropTypes.number.isRequired,
    usdFraction: PropTypes.number.isRequired,
    onBackClick: PropTypes.func.isRequired,
    isScrLoading: PropTypes.bool,
    isUsdLoading: PropTypes.bool,
  };

  static defaultProps = {
    scrValue: '',
    usdValue: '',
    isLoading: false,
    ethAddress: null,
    scrErrorMsg: '',
    usdErrorMsg: '',
    isScrLoading: false,
    isUsdLoading: false,
  };

  onKeyPress = (evt) => {
    const { which, keyCode } = evt;
    const charCode = which || keyCode;
    if ((charCode > CHAR_CODES.CONTROL &&
      ((charCode < CHAR_CODES.ZERO && charCode !== CHAR_CODES.DOT)
      || charCode > CHAR_CODES.NINE))
    ) {
      evt.preventDefault();
    }
  }

  scrChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !checkValidAmountValue(value, this.props.scrFraction)) {
      return;
    }

    this.props.onScrChange(value);
  }

  usdChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !checkValidAmountValue(value, this.props.usdFraction)) {
      return;
    }

    this.props.onUsdChange(value);
  }

  onBackClick = () => {
    GA.event({ category: 'BuySCR', action: 'fiat-Go back' });
    this.props.onBackClick();
  }

  render() {
    const {
      isLoading, ethAddress, scrValue, isScrLoading, scrErrorMsg, usdValue, isUsdLoading, usdErrorMsg,
    } = this.props;

    return (
      <div className="buy-with-card-step">
        <FormattedMessage id="universal.balance.refill.buy-with-card.title">
          {text => <span className="h3 d-block text-center mb-4_5">{text}</span>}
        </FormattedMessage>

        <div className="buy-with-card-step-item d-flex mb-2_5">
          <div className="mr-2 pt-0_5">
            <span className="buy-with-card-step-number d-flex align-items-center justify-content-center rounded-circle border h5p">
              1
            </span>
          </div>

          <div className="align-self-center">
            <FormattedHTMLMessage id="universal.balance.refill.buy-with-card.steps.1" />
          </div>
        </div>

        <div className="buy-with-card-step-item d-flex mb-1_5">
          <div className="mr-2 pt-0_5">
            <span className="buy-with-card-step-number d-flex align-items-center justify-content-center rounded-circle border h5p">
              2
            </span>
          </div>

          <div className="align-self-center">
            <span className=" d-inline-block mb-1_5">
              <FormattedHTMLMessage id="universal.balance.refill.buy-with-card.steps.2" />
            </span>

            <InputWithClipboard value={ethAddress} isLoading={isLoading} onCopyClick={copyClickGA} />
          </div>
        </div>

        <div className="buy-with-card-step-item d-flex mb-3_5">
          <div className="mr-2 pt-0_5">
            <span className="buy-with-card-step-number d-flex align-items-center justify-content-center rounded-circle border h5p">
              3
            </span>
          </div>

          <div className="align-self-center">
            <FormattedMessage id="universal.balance.refill.buy-with-card.steps.3" />
          </div>
        </div>

        <div className="d-flex align-items-center mb-1_5">
          <div className="buy-with-card-step-divider position-relative w-100" />
          <FormattedMessage id="universal.balance.refill.buy-with-card.calc-amount">
            {text => (
              <span className="buy-with-card-step-divider-title text-nowrap mx-1">{text}</span>
            )}
          </FormattedMessage>
          <div className="buy-with-card-step-divider position-relative w-100" />
        </div>

        <div className="d-flex mb-5">
          <InputWithIcon
            icon={<IconUsd />}
            value={usdValue}
            errorMsg={usdErrorMsg}
            onChange={this.usdChangeHandler}
            isLoading={isUsdLoading}
            onKeyPress={this.onKeyPress}
          />
          <span className="h5 mx-1_5 pt-2 modal-content-text-hint">=</span>
          <InputWithIcon
            icon={<IconScr />}
            value={scrValue}
            errorMsg={scrErrorMsg}
            onChange={this.scrChangeHandler}
            isLoading={isScrLoading}
            onKeyPress={this.onKeyPress}
          />
        </div>

        <FormattedMessage id="universal.balance.refill.buy-with-card.button.href">
          {href => (
            <Button color="primary" block tag="a" href={href} onClick={createAccGA} target="_blank" className="mb-1_5">
              <FormattedMessage id="universal.balance.refill.buy-with-card.button.text" />
            </Button>
          )}
        </FormattedMessage>

        <div className="text-center">
          <FormattedMessage id="universal.balance.refill.buy-with-card.back">
            {text => (
              <span
                role="button"
                tabIndex="0"
                className="buy-with-card-step-back text-small"
                onClick={this.onBackClick}
                onKeyPress={this.onBackClick}
              >
                ←{text}
              </span>
            )}
          </FormattedMessage>
        </div>
      </div>
    );
  }
}
